Package: dfdr
Type: Package
Title: Automatic Differentiation of Simple Functions
Version: 0.2.0
Authors@R: c(person("Thomas", "Mailund", role = "aut"), person("Konrad", "Krämer", role = c("aut", "cre"), email = "konrad_kraemer@yahoo.de") )
Description: Implementation of automatically computing derivatives
    of functions (see Mailund Thomas (2017) <doi:10.1007/978-1-4842-2881-4>). Moreover, calculating gradients, Hessian and Jacobian matrices is possible.
License: GPL-3
Encoding: UTF-8
Imports: methods, purrr, rlang, R6, pryr
Suggests: tinytest
NeedsCompilation: no
Packaged: 2023-02-23 07:11:23 UTC; konrad
Author: Thomas Mailund [aut],
  Konrad Krämer [aut, cre]
Maintainer: Konrad Krämer <konrad_kraemer@yahoo.de>
Repository: CRAN
Date/Publication: 2023-02-23 10:30:02 UTC
Built: R 4.2.0; ; 2023-02-23 11:38:57 UTC; unix
