export(d)
export(fcts)
export(fcts_add_fct)
export(gradient)
export(hessian)
export(jacobian)
export(simplify)
importFrom(R6,R6Class)
importFrom(methods,formalArgs)
importFrom(methods,new)
importFrom(pryr,modify_lang)
importFrom(stats,setNames)
